==> openreview_py-1.0.15-py2.py3-none-any.whl: openreview/conference/templates/submissionProcess.js <==
function processUpdate() {
  var or3client = lib.or3client;

  var CONFERENCE_ID = '';
  var SHORT_PHRASE = '';
  var PROGRAM_CHAIRS_ID = '';
  var AREA_CHAIRS_ID = '';
  var OFFICIAL_REVIEW_NAME = '';
  var CREATE_GROUPS = false;

  var authorSubject = SHORT_PHRASE + ' has received your submission titled ' + note.content.title;
  var noteAbstract = (note.content.abstract ? `\n\nAbstract: ${note.content.abstract}` : '');
  var action = note.ddate ? 'deleted' : (existingNote ? 'updated' : 'posted');
  var authorMessage = `Your submission to ${SHORT_PHRASE} has been ${action}.\n\nSubmission Number: ${note.number} \n\nTitle: ${note.content.title} ${noteAbstract} \n\nTo view your submission, click here: ${baseUrl}/forum?id=${note.forum}`;

  var authorMail = {
    groups: [note.tauthor],
    subject: authorSubject,
    message: authorMessage
  };

  authorMessage += `\n\nIf you are not an author of this submission and would like to be removed, please contact the author who added you at ${note.tauthor}`;

  var otherAuthorsMail = {
    groups: note.content.authorids,
    ignoreGroups: [note.tauthor],
    subject: authorSubject,
    message: authorMessage
  };


  let createGroups = async function() {
    if (CREATE_GROUPS && action == 'posted') {
      let committee = [CONFERENCE_ID];
      if (AREA_CHAIRS_ID) {
        committee.push(AREA_CHAIRS_ID);
      }
      const paperGroup = {
        id: CONFERENCE_ID + '/Paper' + note.number,
        signatures: [CONFERENCE_ID],
        writers: committee,
        members: [],
        readers: committee,
        signatories: committee
      };

      await or3client.or3request(or3client.grpUrl, paperGroup, 'POST', token);

      const authorGroupId = paperGroup.id + '/Authors';
      const authorGroup = {
        id: authorGroupId,
        signatures: [CONFERENCE_ID],
        writers: [CONFERENCE_ID],
        members: note.content.authorids.concat(note.signatures),
        readers: [CONFERENCE_ID, authorGroupId],
        signatories: [CONFERENCE_ID, authorGroupId]
      };

      await or3client.or3request(or3client.grpUrl, authorGroup, 'POST', token);

      const reviewerGroupId = paperGroup.id + '/Reviewers';
      const reviewerGroup = {
        id: reviewerGroupId,
        signatures: [CONFERENCE_ID],
        writers: committee,
        members: [],
        readers: committee.concat(reviewerGroupId),
        signatories: committee,
        nonreaders: [authorGroupId]
      };

      await or3client.or3request(or3client.grpUrl, reviewerGroup, 'POST', token);

      const reviewerSubmittedGroupId = reviewerGroupId + '/Submitted';
      const reviewerSubmittedGroup = {
        id: reviewerSubmittedGroupId,
        signatures: [CONFERENCE_ID],
        writers: committee,
        members: [],
        readers: committee.concat(reviewerSubmittedGroupId),
        signatories: committee,
        nonreaders: [authorGroupId]
      };

      await or3client.or3request(or3client.grpUrl, reviewerSubmittedGroup, 'POST', token);

      if (OFFICIAL_REVIEW_NAME) {
        const officialReviewInvitation = {
          id: paperGroup.id + '/-/' + OFFICIAL_REVIEW_NAME,
          super: CONFERENCE_ID + '/-/' + OFFICIAL_REVIEW_NAME,
          signatures: [CONFERENCE_ID],
          writers: [CONFERENCE_ID],
          invitees: [reviewerGroupId],
          reply: {
            forum: note.id,
            replyto: note.id,
            readers: {
              values: ['everyone'],
              description: "User groups that should be able to read this review."
            },
            writers: {
              'values-regex': paperGroup.id + '/AnonReviewer[0-9]+'
            },
            signatures: {
              'values-regex': paperGroup.id + '/AnonReviewer[0-9]+'
            }
          }
        };

        await or3client.or3request(or3client.inviteUrl, officialReviewInvitation, 'POST', token);
      }

    }

    return Promise.resolve();
  }

  let sendEmails = function() {
    var promises = [
      or3client.or3request(or3client.mailUrl, authorMail, 'POST', token),
      or3client.or3request(or3client.mailUrl, otherAuthorsMail, 'POST', token)
    ];

    if (PROGRAM_CHAIRS_ID && action == 'posted') {
      var pcsMail = {
        groups: [PROGRAM_CHAIRS_ID],
        subject: SHORT_PHRASE + ' has received a new submission titled ' + note.content.title,
        message: `A submission to ${SHORT_PHRASE} has been ${action}.

        Submission Number: ${note.number}
        Title: ${note.content.title} ${noteAbstract}

        To view the submission, click here: ${baseUrl}/forum?id=${note.forum}`
      };
      promises.push(or3client.or3request(or3client.mailUrl, pcsMail, 'POST', token));
    }
    return Promise.all(promises);
  }

  createGroups()
  .then(() => sendEmails())
  .then(() => done())
  .catch(error => done(error));

  return true;
}

==> openreview_py-1.0.20-py2.py3-none-any.whl: openreview/conference/templates/submissionProcess.js <==
function processUpdate() {
  var or3client = lib.or3client;

  var CONFERENCE_ID = '';
  var SHORT_PHRASE = '';
  var PROGRAM_CHAIRS_ID = '';
  var AREA_CHAIRS_ID = '';
  var OFFICIAL_REVIEW_NAME = '';
  var CREATE_GROUPS = false;

  var authorSubject = SHORT_PHRASE + ' has received your submission titled ' + note.content.title;
  var noteAbstract = (note.content.abstract ? `\n\nAbstract: ${note.content.abstract}` : '');
  var action = note.ddate ? 'deleted' : (existingNote ? 'updated' : 'posted');
  var authorMessage = `Your submission to ${SHORT_PHRASE} has been ${action}.\n\nSubmission Number: ${note.number} \n\nTitle: ${note.content.title} ${noteAbstract} \n\nTo view your submission, click here: ${baseUrl}/forum?id=${note.forum}`;

  var authorMail = {
    groups: [note.tauthor],
    subject: authorSubject,
    message: authorMessage
  };

  authorMessage += `\n\nIf you are not an author of this submission and would like to be removed, please contact the author who added you at ${note.tauthor}`;

  var otherAuthorsMail = {
    groups: note.content.authorids,
    ignoreGroups: [note.tauthor],
    subject: authorSubject,
    message: authorMessage
  };


  let createGroups = async function() {
    if (CREATE_GROUPS && action == 'posted') {
      let committee = [CONFERENCE_ID];
      if (AREA_CHAIRS_ID) {
        committee.push(AREA_CHAIRS_ID);
      }
      const paperGroup = {
        id: CONFERENCE_ID + '/Paper' + note.number,
        signatures: [CONFERENCE_ID],
        writers: committee,
        members: [],
        readers: committee,
        signatories: committee
      };

      await or3client.or3request(or3client.grpUrl, paperGroup, 'POST', token);

      const authorGroupId = paperGroup.id + '/Authors';
      const authorGroup = {
        id: authorGroupId,
        signatures: [CONFERENCE_ID],
        writers: [CONFERENCE_ID],
        members: note.content.authorids.concat(note.signatures),
        readers: [CONFERENCE_ID, authorGroupId],
        signatories: [CONFERENCE_ID, authorGroupId]
      };

      await or3client.or3request(or3client.grpUrl, authorGroup, 'POST', token);

      const reviewerGroupId = paperGroup.id + '/Reviewers';
      const reviewerGroup = {
        id: reviewerGroupId,
        signatures: [CONFERENCE_ID],
        writers: committee,
        members: [],
        readers: committee.concat(reviewerGroupId),
        signatories: committee,
        nonreaders: [authorGroupId]
      };

      await or3client.or3request(or3client.grpUrl, reviewerGroup, 'POST', token);

      const reviewerSubmittedGroupId = reviewerGroupId + '/Submitted';
      const reviewerSubmittedGroup = {
        id: reviewerSubmittedGroupId,
        signatures: [CONFERENCE_ID],
        writers: committee,
        members: [],
        readers: committee.concat(reviewerSubmittedGroupId),
        signatories: committee,
        nonreaders: [authorGroupId]
      };

      await or3client.or3request(or3client.grpUrl, reviewerSubmittedGroup, 'POST', token);

      if (OFFICIAL_REVIEW_NAME) {
        const officialReviewInvitation = {
          id: paperGroup.id + '/-/' + OFFICIAL_REVIEW_NAME,
          super: CONFERENCE_ID + '/-/' + OFFICIAL_REVIEW_NAME,
          signatures: [CONFERENCE_ID],
          writers: [CONFERENCE_ID],
          invitees: [reviewerGroupId],
          reply: {
            forum: note.id,
            replyto: note.id,
            readers: {
              values: ['everyone'],
              description: "User groups that should be able to read this review."
            },
            writers: {
              'values-regex': paperGroup.id + '/(AnonReviewer|Reviewer_)'
            },
            signatures: {
              'values-regex': paperGroup.id + '/(AnonReviewer|Reviewer_)'
            }
          }
        };

        await or3client.or3request(or3client.inviteUrl, officialReviewInvitation, 'POST', token);
      }

    }

    return Promise.resolve();
  }

  let sendEmails = function() {
    var promises = [
      or3client.or3request(or3client.mailUrl, authorMail, 'POST', token),
      or3client.or3request(or3client.mailUrl, otherAuthorsMail, 'POST', token)
    ];

    if (PROGRAM_CHAIRS_ID && action == 'posted') {
      var pcsMail = {
        groups: [PROGRAM_CHAIRS_ID],
        subject: SHORT_PHRASE + ' has received a new submission titled ' + note.content.title,
        message: `A submission to ${SHORT_PHRASE} has been ${action}.

        Submission Number: ${note.number}
        Title: ${note.content.title} ${noteAbstract}

        To view the submission, click here: ${baseUrl}/forum?id=${note.forum}`
      };
      promises.push(or3client.or3request(or3client.mailUrl, pcsMail, 'POST', token));
    }
    return Promise.all(promises);
  }

  createGroups()
  .then(() => sendEmails())
  .then(() => done())
  .catch(error => done(error));

  return true;
}
